from pygments.style import Style
from pygments.token import Keyword, Name, Comment, String, Error, Number, Operator, Generic, Punctuation, Other


class VscStyle(Style):
    """
    A pygments style inspired by vsc.
    """
    background_color = "#1e1e1e"
    highlight_color  = "#264f78"
    default_style = ""
    styles = {
        Comment: "#6A9955",
        String: "#CE9178",
        Number: "#B5CEA8",
        Name: "#D4D4D4",
        Name.Decorator: "#DCDCAA",
        Name.Function: "#DCDCAA",
        Name.Class: "#DCDCAA",
        Name.Variable: "#9fb4c3",
        Name.Builtins: "#4EC9B0",
        Name.Constant: "#9fb4c3",
        Keyword: "italic bold #569CD6",
        Generic: "#D4D4D4",
        Generic.Emph: "italic",
        Generic.Strong: "bold",
        Generic.Heading: "bold",
        Generic.Subheading: "bold",
        Punctuation: "bold #D4D4D4",
        Operator: "#D4D4D4",
        Operator.Word: "#569CD6",
        Other: "#D4D4D4",
        Error: "#F44747",
        
        
    }


from setuptools import setup

setup(
    name='pygments_vsc_style',
    author="Cryptex",
    url='https://github.com/Cryptex-github/pygments-vsc-style',
    project_urls={
        "Issue tracker": "https://github.com/Cryptex-github/pygments-vsc-style/issues",
    },
    version="0.0.2",
    packages=[
        "pygments_vsc_style"
    ],
    license='MIT',
    description='A pygments style inspired by vsc.',
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    include_package_data=True,
    install_requires=[
        'pygments>=2.9.0'
    ],
    entry_points="""
[pygments.styles]
vsc = pygments_vsc_style:VscStyle
    """,
    python_requires='>=3.8.0',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ]
)